/*
 *  Copyright (c) 2014 Boudewijn Rempt <boud@valdyas.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#ifndef KIS_ABOUT_APPLICATION_H
#define KIS_ABOUT_APPLICATION_H

#include <QDialog>
#include <QList>

#include <kaboutdata.h>

class KisAboutApplication : public QDialog
{
    Q_OBJECT
public:
    explicit KisAboutApplication(QWidget *parent = 0);


private:
    QWidget *createTranslatorsWidget(const QList<KAboutPerson> &translators,
                                     const QString &ocsProviderUrl);
};



#endif // KIS_ABOUT_APPLICATION_H
